@@ -6,14 +6,15 @@ A module to wrap (non-Windows) archive calls
 '''
 from __future__ import absolute_import
 import contextlib  # For < 2.7 compat
+import copy
 import errno
 import logging
 import os
 import re
 import shlex
 import stat
+import subprocess
 import tarfile
-import tempfile
 import zipfile
 try:
     from shlex import quote as _quote  # pylint: disable=E0611
@@ -157,7 +158,10 @@ def list_(name,
         files = []
         links = []
         try:
-            with contextlib.closing(tarfile.open(cached)) as tar_archive:
+            open_kwargs = {'name': cached} \
+                if not isinstance(cached, subprocess.Popen) \
+                else {'fileobj': cached.stdout, 'mode': 'r|'}
+            with contextlib.closing(tarfile.open(**open_kwargs)) as tar_archive:
                 for member in tar_archive.getmembers():
                     if member.issym():
                         links.append(member.name)
@@ -168,7 +172,15 @@ def list_(name,
             return dirs, files, links
 
         except tarfile.ReadError:
-            if not failhard:
+            if failhard:
+                if isinstance(cached, subprocess.Popen):
+                    stderr = cached.communicate()[1]
+                    if cached.returncode != 0:
+                        raise CommandExecutionError(
+                            'Failed to decompress {0}'.format(name),
+                            info={'error': stderr}
+                        )
+            else:
                 if not salt.utils.which('tar'):
                     raise CommandExecutionError('\'tar\' command not available')
                 if decompress_cmd is not None:
@@ -187,29 +199,12 @@ def list_(name,
                         decompress_cmd = 'xz --decompress --stdout'
 
                 if decompress_cmd:
-                    fd, decompressed = tempfile.mkstemp()
-                    os.close(fd)
-                    try:
-                        cmd = '{0} {1} > {2}'.format(decompress_cmd,
-                                                     _quote(cached),
-                                                     _quote(decompressed))
-                        result = __salt__['cmd.run_all'](cmd, python_shell=True)
-                        if result['retcode'] != 0:
-                            raise CommandExecutionError(
-                                'Failed to decompress {0}'.format(name),
-                                info={'error': result['stderr']}
-                            )
-                        return _list_tar(name, decompressed, None, True)
-                    finally:
-                        try:
-                            os.remove(decompressed)
-                        except OSError as exc:
-                            if exc.errno != errno.ENOENT:
-                                log.warning(
-                                    'Failed to remove intermediate '
-                                    'decompressed archive %s: %s',
-                                    decompressed, exc.__str__()
-                                )
+                    decompressed = subprocess.Popen(
+                        '{0} {1}'.format(decompress_cmd, _quote(cached)),
+                        shell=True,
+                        stdout=subprocess.PIPE,
+                        stderr=subprocess.PIPE)
+                    return _list_tar(name, decompressed, None, True)
 
         raise CommandExecutionError(
             'Unable to list contents of {0}. If this is an XZ-compressed tar '
@@ -224,21 +219,40 @@ def list_(name,
         Password-protected ZIP archives can still be listed by zipfile, so
         there is no reason to invoke the unzip command.
         '''
-        dirs = []
+        dirs = set()
         files = []
         links = []
         try:
             with contextlib.closing(zipfile.ZipFile(cached)) as zip_archive:
                 for member in zip_archive.infolist():
-                    mode = member.external_attr >> 16
                     path = member.filename
-                    if stat.S_ISLNK(mode):
-                        links.append(path)
-                    elif stat.S_ISDIR(mode):
-                        dirs.append(path)
+                    if salt.utils.is_windows():
+                        if path.endswith('/'):
+                            # zipfile.ZipInfo objects on windows use forward
+                            # slash at end of the directory name.
+                            dirs.add(path)
+                        else:
+                            files.append(path)
                     else:
-                        files.append(path)
-            return dirs, files, links
+                        mode = member.external_attr >> 16
+                        if stat.S_ISLNK(mode):
+                            links.append(path)
+                        elif stat.S_ISDIR(mode):
+                            dirs.add(path)
+                        else:
+                            files.append(path)
+
+                _files = copy.deepcopy(files)
+                for path in _files:
+                    # ZIP files created on Windows do not add entries
+                    # to the archive for directories. So, we'll need to
+                    # manually add them.
+                    dirname = ''.join(path.rpartition('/')[:2])
+                    if dirname:
+                        dirs.add(dirname)
+                        if dirname in files:
+                            files.remove(dirname)
+            return list(dirs), files, links
         except zipfile.BadZipfile:
             raise CommandExecutionError('{0} is not a ZIP file'.format(name))
 
@@ -366,10 +380,15 @@ def list_(name,
                 item.sort()
 
         if verbose:
-            ret = {'dirs': dirs, 'files': files, 'links': links}
-            ret['top_level_dirs'] = [x for x in dirs if x.count('/') == 1]
-            ret['top_level_files'] = [x for x in files if x.count('/') == 0]
-            ret['top_level_links'] = [x for x in links if x.count('/') == 0]
+            ret = {'dirs': sorted(dirs),
+                   'files': sorted(files),
+                   'links': sorted(links)}
+            ret['top_level_dirs'] = [x for x in ret['dirs']
+                                     if x.count('/') == 1]
+            ret['top_level_files'] = [x for x in ret['files']
+                                      if x.count('/') == 0]
+            ret['top_level_links'] = [x for x in ret['links']
+                                      if x.count('/') == 0]
         else:
             ret = sorted(dirs + files + links)
         return ret
@@ -933,7 +952,7 @@ def unzip(zip_file,
     extract_perms : True
         The Python zipfile_ module does not extract file/directory attributes
         by default. When this argument is set to ``True``, Salt will attempt to
-        apply the file permision attributes to the extracted files/folders.
+        apply the file permission attributes to the extracted files/folders.
 
         On Windows, only the read-only flag will be extracted as set within the
         zip file, other attributes (i.e. user/group permissions) are ignored.
@@ -995,7 +1014,15 @@ def unzip(zip_file,
                             continue
                     zfile.extract(target, dest, password)
                     if extract_perms:
-                        os.chmod(os.path.join(dest, target), zfile.getinfo(target).external_attr >> 16)
+                        perm = zfile.getinfo(target).external_attr >> 16
+                        if perm == 0:
+                            umask_ = os.umask(0)
+                            os.umask(umask_)
+                            if target.endswith('/'):
+                                perm = 0o777 & ~umask_
+                            else:
+                                perm = 0o666 & ~umask_
+                        os.chmod(os.path.join(dest, target), perm)
     except Exception as exc:
         pass
     finally:
