@@ -38,6 +38,7 @@ import re
 
 # Import salt libs
 import salt.utils
+import salt.utils.pkg
 import salt.utils.mac_utils
 from salt.exceptions import CommandExecutionError
 
@@ -389,6 +390,8 @@ def refresh_db():
         salt mac pkg.refresh_db
 
     '''
+    # Remove rtag file to keep multiple refreshes from happening in pkg states
+    salt.utils.pkg.clear_rtag(__opts__)
     cmd = ['port', 'selfupdate']
     return salt.utils.mac_utils.execute_return_success(cmd)
 
