@@ -126,6 +126,11 @@ def _config_logic(loaded_result, test=False, commit_config=True, loaded_config=N
     if _compare.get('result', False):
         loaded_result['diff'] = _compare.get('out')
         loaded_result.pop('out', '')  # not needed
+    else:
+        loaded_result['diff'] = None
+        loaded_result['result'] = False
+        loaded_result['comment'] = _compare.get('comment')
+        return loaded_result
 
     _loaded_res = loaded_result.get('result', False)
 
@@ -538,7 +543,7 @@ def ipaddrs():
     Returns all configured IP addresses on all interfaces as a dictionary of dictionaries.\
     Keys of the main dictionary represent the name of the interface.\
     Values of the main dictionary represent are dictionaries that may consist of two keys\
-    'ipv4' and 'ipv6' (one, both or none) which are themselvs dictionaries witht the IP addresses as keys.\
+    'ipv4' and 'ipv6' (one, both or none) which are themselvs dictionaries with the IP addresses as keys.\
 
     CLI Example:
 
@@ -782,7 +787,7 @@ def load_config(filename=None,
 
     To avoid committing the configuration, set the argument ``test`` to ``True`` and will discard (dry run).
 
-    To keep the chnages but not commit, set ``commit`` to ``False``.
+    To keep the changes but not commit, set ``commit`` to ``False``.
 
     To replace the config, set ``replace`` to ``True``.
 
@@ -800,7 +805,7 @@ def load_config(filename=None,
         Commit? Default: ``True``.
 
     debug: False
-        Debug mode. Will insert a new key under the output dictionary, as ``loaded_config`` contaning the raw
+        Debug mode. Will insert a new key under the output dictionary, as ``loaded_config`` containing the raw
         configuration loaded on the device.
 
         .. versionadded:: 2016.11.2
@@ -889,7 +894,7 @@ def load_template(template_name,
     To avoid committing the configuration, set the argument ``test`` to ``True``
     and will discard (dry run).
 
-    To preserve the chnages, set ``commit`` to ``False``.
+    To preserve the changes, set ``commit`` to ``False``.
     However, this is recommended to be used only in exceptional cases
     when there are applied few consecutive states
     and/or configuration changes.
@@ -913,7 +918,7 @@ def load_template(template_name,
 
         Placing the template under ``/etc/salt/states/templates/example.jinja``,
         it can be used as ``salt://templates/example.jinja``.
-        Alternatively, for local files, the user can specify the abolute path.
+        Alternatively, for local files, the user can specify the absolute path.
         If remotely, the source can be retrieved via ``http``, ``https`` or ``ftp``.
 
         Examples:
@@ -995,7 +1000,7 @@ def load_template(template_name,
 
     debug: False
         Debug mode. Will insert a new key under the output dictionary,
-        as ``loaded_config`` contaning the raw result after the template was rendered.
+        as ``loaded_config`` containing the raw result after the template was rendered.
 
         .. versionadded:: 2016.11.2
 
@@ -1014,7 +1019,7 @@ def load_template(template_name,
 
         .. note::
 
-            Do not explicitely specify this argument.
+            Do not explicitly specify this argument.
             This represents any other variable that will be sent
             to the template rendering system.
             Please see the examples below!
@@ -1153,7 +1158,7 @@ def load_template(template_name,
             if template_path and not file_exists:
                 template_name = __salt__['file.join'](template_path, template_name)
                 if not saltenv:
-                    # no saltenv overriden
+                    # no saltenv overridden
                     # use the custom template path
                     saltenv = template_path if not salt_render else 'base'
             elif salt_render and not saltenv:
@@ -1344,8 +1349,8 @@ def config_control():
     If differences found, will try to commit.
     In case commit unsuccessful, will try to rollback.
 
-    :return: A tuple with a boolean that specifies if the config was changed/commited/rollbacked on the device.\
-    And a string that provides more details of the reason why the configuration was not commited properly.
+    :return: A tuple with a boolean that specifies if the config was changed/committed/rollbacked on the device.\
+    And a string that provides more details of the reason why the configuration was not committed properly.
 
     CLI Example:
 
