@@ -18,7 +18,7 @@ import salt.ext.six as six
 import salt.pillar
 import salt.utils
 from salt.defaults import DEFAULT_TARGET_DELIM
-from salt.exceptions import CommandExecutionError, SaltInvocationError
+from salt.exceptions import CommandExecutionError
 
 __proxyenabled__ = ['*']
 
@@ -28,6 +28,7 @@ log = logging.getLogger(__name__)
 def get(key,
         default=KeyError,
         merge=False,
+        merge_nested_lists=None,
         delimiter=DEFAULT_TARGET_DELIM,
         saltenv=None):
     '''
@@ -51,11 +52,28 @@ def get(key,
 
         pkg:apache
 
-    merge
-        Specify whether or not the retrieved values should be recursively
-        merged into the passed default.
+    merge : ``False``
+        If ``True``, the retrieved values will be merged into the passed
+        default. When the default and the retrieved value are both
+        dictionaries, the dictionaries will be recursively merged.
 
         .. versionadded:: 2014.7.0
+        .. versionchanged:: 2016.3.7,2016.11.4,Nitrogen
+            If the default and the retrieved value are not of the same type,
+            then merging will be skipped and the retrieved value will be
+            returned. Earlier releases raised an error in these cases.
+
+    merge_nested_lists
+        If set to ``False``, lists nested within the retrieved pillar
+        dictionary will *overwrite* lists in ``default``. If set to ``True``,
+        nested lists will be *merged* into lists in ``default``. If unspecified
+        (the default), this option is inherited from the
+        :conf_minion:`pillar_merge_lists` minion config option.
+
+        .. note::
+            This option is ignored when ``merge`` is set to ``False``.
+
+        .. versionadded:: 2016.11.6
 
     delimiter
         Specify an alternate delimiter to use when traversing a nested dict.
@@ -90,36 +108,58 @@ def get(key,
     if not __opts__.get('pillar_raise_on_missing'):
         if default is KeyError:
             default = ''
-    opt_merge_lists = __opts__.get('pillar_merge_lists', False)
+    opt_merge_lists = __opts__.get('pillar_merge_lists', False) if \
+        merge_nested_lists is None else merge_nested_lists
     pillar_dict = __pillar__ if saltenv is None else items(saltenv=saltenv)
 
     if merge:
-        if default is None:
-            log.debug('pillar.get: default is None, skipping merge')
-        else:
-            if not isinstance(default, dict):
-                raise SaltInvocationError(
-                    'default must be a dictionary or None when merge=True'
-                )
+        if isinstance(default, dict):
             ret = salt.utils.traverse_dict_and_list(
                 pillar_dict,
                 key,
                 {},
                 delimiter)
-            if isinstance(ret, collections.Mapping) and \
-                    isinstance(default, collections.Mapping):
+            if isinstance(ret, collections.Mapping):
                 default = copy.deepcopy(default)
                 return salt.utils.dictupdate.update(
                     default,
                     ret,
                     merge_lists=opt_merge_lists)
+            else:
+                log.error(
+                    'pillar.get: Default (%s) is a dict, but the returned '
+                    'pillar value (%s) is of type \'%s\'. Merge will be '
+                    'skipped.', default, ret, type(ret).__name__
+                )
+        elif isinstance(default, list):
+            ret = salt.utils.traverse_dict_and_list(
+                pillar_dict,
+                key,
+                [],
+                delimiter)
+            if isinstance(ret, list):
+                default = copy.deepcopy(default)
+                default.extend([x for x in ret if x not in default])
+                return default
+            else:
+                log.error(
+                    'pillar.get: Default (%s) is a list, but the returned '
+                    'pillar value (%s) is of type \'%s\'. Merge will be '
+                    'skipped.', default, ret, type(ret).__name__
+                )
+        else:
+            log.error(
+                'pillar.get: Default (%s) is of type \'%s\', must be a dict '
+                'or list to merge. Merge will be skipped.',
+                default, type(default).__name__
+            )
 
     ret = salt.utils.traverse_dict_and_list(pillar_dict,
                                             key,
                                             default,
                                             delimiter)
     if ret is KeyError:
-        raise KeyError("Pillar key not found: {0}".format(key))
+        raise KeyError('Pillar key not found: {0}'.format(key))
 
     return ret
 
