@@ -12,10 +12,6 @@ or for problem solving if your minion is having problems.
 
 # Import Python Libs
 from __future__ import absolute_import
-import os
-import ctypes
-import sys
-import time
 import datetime
 import logging
 
@@ -23,23 +19,28 @@ log = logging.getLogger(__name__)
 
 # Import Salt Libs
 import salt.utils
-import salt.ext.six as six
 import salt.utils.event
 from salt._compat import subprocess
 from salt.utils.network import host_to_ips as _host_to_ips
+from salt.utils import namespaced_function as _namespaced_function
+
+# These imports needed for namespaced functions
 # pylint: disable=W0611
 from salt.modules.status import ping_master, time_
 import copy
 # pylint: enable=W0611
-from salt.utils import namespaced_function as _namespaced_function
 
 # Import 3rd Party Libs
+HAS_WMI = False
 if salt.utils.is_windows():
     import wmi
     import salt.utils.winapi
     HAS_WMI = True
-else:
-    HAS_WMI = False
+
+HAS_PSUTIL = False
+if salt.utils.is_windows():
+    import psutil
+    HAS_PSUTIL = True
 
 __opts__ = {}
 __virtualname__ = 'status'
@@ -55,6 +56,9 @@ def __virtual__():
     if not HAS_WMI:
         return False, 'win_status.py: Requires WMI and WinAPI'
 
+    if not HAS_PSUTIL:
+        return False, 'win_status.py: Requires psutil'
+
     # Namespace modules from `status.py`
     global ping_master, time_
     ping_master = _namespaced_function(ping_master, globals())
@@ -79,10 +83,7 @@ def cpuload():
 
        salt '*' status.cpuload
     '''
-
-    # Pull in the information from WMIC
-    cmd = ['wmic', 'cpu', 'get', 'loadpercentage', '/value']
-    return int(__salt__['cmd.run'](cmd).split('=')[1])
+    return psutil.cpu_percent()
 
 
 def diskusage(human_readable=False, path=None):
@@ -103,29 +104,22 @@ def diskusage(human_readable=False, path=None):
     if not path:
         path = 'c:/'
 
-    # Credit for the source and ideas for this function:
-    # http://code.activestate.com/recipes/577972-disk-usage/?in=user-4178764
-    _, total, free = \
-        ctypes.c_ulonglong(), ctypes.c_ulonglong(), ctypes.c_longlong()
-    if sys.version_info >= (3, ) or isinstance(path, six.text_type):
-        fun = ctypes.windll.kernel32.GetDiskFreeSpaceExW
-    else:
-        fun = ctypes.windll.kernel32.GetDiskFreeSpaceExA
-    ret = fun(path, ctypes.byref(_), ctypes.byref(total), ctypes.byref(free))
-    if ret == 0:
-        raise ctypes.WinError()
-    used = total.value - free.value
+    disk_stats = psutil.disk_usage(path)
 
-    total_val = total.value
-    used_val = used
-    free_val = free.value
+    total_val = disk_stats.total
+    used_val = disk_stats.used
+    free_val = disk_stats.free
+    percent = disk_stats.percent
 
     if human_readable:
         total_val = _byte_calc(total_val)
         used_val = _byte_calc(used_val)
         free_val = _byte_calc(free_val)
 
-    return {'total': total_val, 'used': used_val, 'free': free_val}
+    return {'total': total_val,
+            'used': used_val,
+            'free': free_val,
+            'percent': percent}
 
 
 def procs(count=False):
@@ -176,16 +170,17 @@ def saltmem(human_readable=False):
         salt '*' status.saltmem
         salt '*' status.saltmem human_readable=True
     '''
-    with salt.utils.winapi.Com():
-        wmi_obj = wmi.WMI()
-        result = wmi_obj.query(
-            'SELECT WorkingSet FROM Win32_PerfRawData_PerfProc_Process '
-            'WHERE IDProcess={0}'.format(os.getpid())
-        )
-        mem = int(result[0].wmi_property('WorkingSet').value)
-        if human_readable:
-            return _byte_calc(mem)
-        return mem
+    # psutil.Process defaults to current process (`os.getpid()`)
+    p = psutil.Process()
+
+    # Use oneshot to get a snapshot
+    with p.oneshot():
+        mem = p.memory_info().rss
+
+    if human_readable:
+        return _byte_calc(mem)
+
+    return mem
 
 
 def uptime(human_readable=False):
@@ -204,15 +199,8 @@ def uptime(human_readable=False):
        salt '*' status.uptime
        salt '*' status.uptime human_readable=True
     '''
-
-    # Open up a subprocess to get information from WMIC
-    cmd = ['wmic', 'os', 'get', 'lastbootuptime', '/value']
-    startup_time = __salt__['cmd.run'](cmd).split('=')[1][:14]
-
-    # Convert to time struct
-    startup_time = time.strptime(startup_time, '%Y%m%d%H%M%S')
-    # Convert to datetime object
-    startup_time = datetime.datetime(*startup_time[:6])
+    # Get startup time
+    startup_time = datetime.datetime.fromtimestamp(psutil.boot_time())
 
     # Subtract startup time from current time to get the uptime of the system
     uptime = datetime.datetime.now() - startup_time
