@@ -848,6 +848,7 @@ def create_private_key(path=None,
 
 def create_crl(  # pylint: disable=too-many-arguments,too-many-locals
         path=None, text=False, signing_private_key=None,
+        signing_private_key_passphrase=None,
         signing_cert=None, revoked=None, include_expired=False,
         days_valid=100, digest=''):
     '''
@@ -866,6 +867,9 @@ def create_crl(  # pylint: disable=too-many-arguments,too-many-locals
         A path or string of the private key in PEM format that will be used
         to sign this crl. This is required.
 
+    signing_private_key_passphrase:
+        Passphrase to decrypt the private key.
+
     signing_cert:
         A certificate matching the private key that will be used to sign
         this crl. This is required.
@@ -875,7 +879,7 @@ def create_crl(  # pylint: disable=too-many-arguments,too-many-locals
         represents one certificate. A dict must contain either the key
         ``serial_number`` with the value of the serial number to revoke, or
         ``certificate`` with either the PEM encoded text of the certificate,
-        or a path ot the certificate to revoke.
+        or a path to the certificate to revoke.
 
         The dict can optionally contain the ``revocation_date`` key. If this
         key is omitted the revocation date will be set to now. If should be a
@@ -969,26 +973,30 @@ def create_crl(  # pylint: disable=too-many-arguments,too-many-locals
     cert = OpenSSL.crypto.load_certificate(
         OpenSSL.crypto.FILETYPE_PEM,
         get_pem_entry(signing_cert, pem_type='CERTIFICATE'))
-    signing_private_key = _text_or_file(signing_private_key)
+    signing_private_key = _get_private_key_obj(signing_private_key,
+                                               passphrase=signing_private_key_passphrase).as_pem(cipher=None)
     key = OpenSSL.crypto.load_privatekey(
         OpenSSL.crypto.FILETYPE_PEM,
         get_pem_entry(signing_private_key))
 
+    export_kwargs = {
+        'cert': cert,
+        'key': key,
+        'type': OpenSSL.crypto.FILETYPE_PEM,
+        'days': days_valid
+    }
+    if digest:
+        export_kwargs['digest'] = bytes(digest)
+    else:
+        log.warning('No digest specified. The default md5 digest will be used.')
+
     try:
-        crltext = crl.export(
-            cert,
-            key,
-            OpenSSL.crypto.FILETYPE_PEM,
-            days=days_valid,
-            digest=bytes(digest))
-    except TypeError:
+        crltext = crl.export(**export_kwargs)
+    except (TypeError, ValueError):
         log.warning(
             'Error signing crl with specified digest. Are you using pyopenssl 0.15 or newer? The default md5 digest will be used.')
-        crltext = crl.export(
-            cert,
-            key,
-            OpenSSL.crypto.FILETYPE_PEM,
-            days=days_valid)
+        export_kwargs.pop('digest', None)
+        crltext = crl.export(**export_kwargs)
 
     if text:
         return crltext
@@ -1417,6 +1425,9 @@ def create_certificate(
     # If neither public_key or csr are included, this cert is self-signed
     if 'public_key' not in kwargs and 'csr' not in kwargs:
         kwargs['public_key'] = kwargs['signing_private_key']
+        if 'signing_private_key_passphrase' in kwargs:
+            kwargs['public_key_passphrase'] = kwargs[
+                'signing_private_key_passphrase']
 
     csrexts = {}
     if 'csr' in kwargs:
@@ -1581,8 +1592,17 @@ def create_csr(path=None, text=False, **kwargs):
     if 'public_key' not in kwargs:
         kwargs['public_key'] = kwargs['private_key']
 
+    if 'private_key_passphrase' not in kwargs:
+        kwargs['private_key_passphrase'] = None
     if 'public_key_passphrase' not in kwargs:
         kwargs['public_key_passphrase'] = None
+    if kwargs['public_key_passphrase'] and not kwargs[
+            'private_key_passphrase']:
+        kwargs['private_key_passphrase'] = kwargs['public_key_passphrase']
+    if kwargs['private_key_passphrase'] and not kwargs[
+            'public_key_passphrase']:
+        kwargs['public_key_passphrase'] = kwargs['private_key_passphrase']
+
     csr.set_pubkey(get_public_key(kwargs['public_key'],
                                   passphrase=kwargs['public_key_passphrase'], asObj=True))
 
@@ -1604,6 +1624,9 @@ def create_csr(path=None, text=False, **kwargs):
             critical = True
             extval = extval[9:]
 
+        if extname == 'subjectKeyIdentifier' and 'hash' in extval:
+            extval = extval.replace('hash', _get_pubkey_hash(csr))
+
         if extname == 'subjectAltName':
             extval = extval.replace('IP Address', 'IP')
 
@@ -1623,7 +1646,7 @@ def create_csr(path=None, text=False, **kwargs):
     csr.add_extensions(extstack)
 
     csr.sign(_get_private_key_obj(kwargs['private_key'],
-                                  passphrase=kwargs['public_key_passphrase']), kwargs['algorithm'])
+                                  passphrase=kwargs['private_key_passphrase']), kwargs['algorithm'])
 
     if path:
         return write_pem(
